@@ -1,3 +1,4 @@
+from copy import copy
 from django.conf import settings
 from django.core.files import File
 from django.core.files.images import ImageFile
@@ -129,6 +130,14 @@ class ImageCacheFile(BaseIKFile, ImageFile):
         existence_required.send(sender=self, file=self)
         return self.cachefile_backend.exists(self)
 
+    def __getstate__(self):
+        state = copy(self.__dict__)
+
+        # file is hidden link to "file" attribute
+        state.pop('_file', None)
+
+        return state
+
 
 class LazyImageCacheFile(SimpleLazyObject):
     def __init__(self, generator_id, *args, **kwargs):
